@@ -11,8 +11,50 @@ import React from 'react';
 import {IModeSwitchProps} from '../slider';
 import {CreationWidget} from './creation-widget';
 import {ErrorWidget} from './error-widget';
-import {Switch} from "@blueprintjs/core";
+import {Stack, styled, Switch, Typography} from "@mui/material";
+import {Validator} from "./validator";
 
+export const AntSwitch = styled(Switch)(({ theme }) => ({
+  width: 28,
+  height: 16,
+  padding: 0,
+  display: 'flex',
+  '&:active': {
+    '& .MuiSwitch-thumb': {
+      width: 15,
+    },
+    '& .MuiSwitch-switchBase.Mui-checked': {
+      transform: 'translateX(9px)',
+    },
+  },
+  '& .MuiSwitch-switchBase': {
+    padding: 2,
+    '&.Mui-checked': {
+      transform: 'translateX(12px)',
+      color: '#fff',
+      '& + .MuiSwitch-track': {
+        opacity: 1,
+        backgroundColor: theme.palette.mode === 'dark' ? '#177ddc' : '#1890ff',
+      },
+    },
+  },
+  '& .MuiSwitch-thumb': {
+    boxShadow: '0 2px 4px 0 rgb(0 35 11 / 20%)',
+    width: 12,
+    height: 12,
+    borderRadius: 6,
+    transition: theme.transitions.create(['width'], {
+      duration: 200,
+    }),
+  },
+  '& .MuiSwitch-track': {
+    borderRadius: 16 / 2,
+    opacity: 1,
+    backgroundColor:
+      theme.palette.mode === 'dark' ? 'rgba(255,255,255,.35)' : 'rgba(0,0,0,.25)',
+    boxSizing: 'border-box',
+  },
+}));
 
 export class CreationModeSwitch extends React.Component<IModeSwitchProps> {
   public state = {
@@ -52,13 +94,11 @@ export class CreationModeSwitch extends React.Component<IModeSwitchProps> {
 
   public render() {
     return (
-      <span>
-        <Switch className={"jp-Toolbar-item"}
-                style={{marginTop: "-1px"}}
-                checked={this.state.mode}
-                label="Creation Mode"
-                onChange={this.handleChange}/>
-      </span>
+        <Stack direction="row" spacing={1}  alignItems={"center"} >
+        <AntSwitch checked={this.state.mode} onChange={this.handleChange}/>
+        <Typography variant="caption" >Creation Mode</Typography>
+        <Validator notebook={this.notebook}/>
+      </Stack>
     );
   }
 }
