@@ -4,9 +4,6 @@
 // This source code is licensed under the BSD-style license found in the
 // LICENSE file in the root directory of this source tree.
 
-import { Notebook } from '@jupyterlab/notebook';
-import { Button } from '@blueprintjs/core';
-import { Cell } from '@jupyterlab/cells';
 import * as React from 'react';
 
 import { Alert } from '@mui/material';
