@@ -35,6 +35,39 @@ export async function pullFeedback(
   );
 }
 
+export async function pullSubmissionFiles(
+  lecture: Lecture,
+  assignment: Assignment,
+  submission: Submission
+) {
+  let url = `/lectures/${lecture.id}/assignments/${assignment.id}/pull/edit`
+
+  const searchParams = new URLSearchParams({
+    subid: String(submission.id)
+  });
+  url += '?' + searchParams;
+  return request<void>(
+    HTTPMethod.GET,
+    url
+  );
+}
+
+export async function pushSubmissionFiles(
+  lecture: Lecture,
+  assignment: Assignment,
+  submission: Submission
+) {
+  let url = `/lectures/${lecture.id}/assignments/${assignment.id}/push/edit`
+  const searchParams = new URLSearchParams({
+    subid: String(submission.id)
+  });
+  url += '?' + searchParams;
+  return request<void>(
+    HTTPMethod.PUT,
+    url
+  );
+}
+
 export function getSubmissions(
   lecture: Lecture,
   assignment: Assignment,
@@ -97,6 +130,24 @@ export function getProperties(
   return request<any>(HTTPMethod.GET, url, reload);
 }
 
+export function getLogs(
+  lectureId: number,
+  assignmentId: number,
+  submissionId: number,
+  reload = false
+): Promise<string> {
+  const url = `/lectures/${lectureId}/assignments/${assignmentId}/submissions/${submissionId}/logs`;
+  return request<string>(HTTPMethod.GET, url, reload);
+}
+
+export function createOrOverrideEditRepository(
+  lectureId: number,
+  assignmentId: number,
+  submissionId: number): Promise<Submission> {
+  const url = `/lectures/${lectureId}/assignments/${assignmentId}/submissions/${submissionId}/edit`;
+  return request<Submission>(HTTPMethod.PUT, url, {});
+}
+
 export function updateProperties(
   lectureId: number,
   assignmentId: number,
